==> IBM_Storage_Driver_for_OpenStack_1.1.1-b327.tar.gz: IBM_Storage_Driver_for_OpenStack_1.1.1-b327/runtime/runner.py <==
#----------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2012
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-----------------------------------------------------------------------------

import sys
import os

MODULES_LOOKUP = {
    'install.sh' : ('wizards.install', 'InstallWizard'),
    'uninstall.sh' : ('wizards.uninstall', 'UninstallWizard'),
    'patch_nova_compute.sh' : ('wizards.patch', 'PatchWizard'),
    'unpatch_nova_compute.sh' : ('wizards.unpatch', 'UnpatchWizard'),
}

def set_python_path(path):
    for egg in [os.path.join(path, egg) for egg in os.listdir(path) if egg.endswith(".egg")]:
        sys.path.insert(0, egg)

def main():
    runner = sys.argv.pop(0)
    base_path = sys.argv.pop(0)
    set_python_path(os.path.dirname(runner))
    executable_name = sys.argv.pop(0)
    full_executable = os.path.join(base_path, executable_name)
    if executable_name not in MODULES_LOOKUP:
        sys.exit('Unknown runner!')
    namespace , object_to_run = MODULES_LOOKUP[executable_name]
    fullnamespace = 'xiv_openstack.' + namespace
    module = __import__(fullnamespace, globals(), locals(), [namespace], -1)
    args = [full_executable] + sys.argv

    to_run = getattr(module, object_to_run, None)

    to_run.main(*args)

if __name__ == '__main__':
    main()

==> IBM_Storage_Driver_for_OpenStack_1.5.0-b643.tar.gz: IBM_Storage_Driver_for_OpenStack_1.5.0-b643/runtime/runner.py <==
#----------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2012
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-----------------------------------------------------------------------------

import sys
import os

MODULES_LOOKUP = {
    'install.sh': ('wizards.install', 'InstallWizard'),
    'configure.sh': ('wizards.configure', 'ConfigureWizard'),
    'uninstall.sh': ('wizards.uninstall', 'UninstallWizard'),
    'create_volume_types.sh': ('wizards.vol_types', 'CreateVolTypesWizard'),
}


def set_python_path(path):
    for egg in [os.path.join(path, egg) for egg in os.listdir(path) if egg.endswith(".egg")]:
        sys.path.insert(0, egg)


def main():
    runner = sys.argv.pop(0)
    base_path = sys.argv.pop(0)
    set_python_path(os.path.dirname(runner))
    executable_name = sys.argv.pop(0)
    full_executable = os.path.join(base_path, executable_name)
    if executable_name not in MODULES_LOOKUP:
        sys.exit('Unknown runner!')
    namespace, object_to_run = MODULES_LOOKUP[executable_name]
    fullnamespace = 'xiv_ds8k_openstack.' + namespace
    module = __import__(fullnamespace, globals(), locals(), [namespace], -1)
    args = [full_executable] + sys.argv

    to_run = getattr(module, object_to_run, None)

    to_run.main(*args)

if __name__ == '__main__':
    main()
